@@ -1,4 +1,4 @@
-import au.id.jericho.lib.html.*;
+import net.htmlparser.jericho.*;
 import java.util.*;
 import java.io.*;
 import java.net.*;
@@ -16,9 +16,8 @@ public class DisplayAllElements {
 		PHPTagTypes.PHP_SHORT.deregister(); // remove PHP short tags for this example otherwise they override processing instructions
 		MasonTagTypes.register();
 		Source source=new Source(new URL(sourceUrlString));
-		List elementList=source.findAllElements();
-		for (Iterator i=elementList.iterator(); i.hasNext();) {
-			Element element=(Element)i.next();
+		List<Element> elementList=source.getAllElements();
+		for (Element element : elementList) {
 			System.out.println("-------------------------------------------------------------------------------");
 			System.out.println(element.getDebugInfo());
 			if (element.getAttributes()!=null) System.out.println("XHTML StartTag:\n"+element.getStartTag().tidy(true));
