@@ -1,4 +1,4 @@
-import au.id.jericho.lib.html.*;
+import net.htmlparser.jericho.*;
 import java.util.*;
 import java.io.*;
 import java.net.*;
